Index: lib/filterValidation.js |
=================================================================== |
--- a/lib/filterValidation.js |
+++ b/lib/filterValidation.js |
@@ -21,14 +21,14 @@ |
* Parses and validates a filter given by the user. |
* |
* @param {string} text |
* @param {Boolean} [ignore_headers=false] If true, no exception is raised |
* for filter list headers, instead |
* the function will return null. |
* @return {Filter} |
* @throws Will throw an exception if filter cannot be |
* parsed or contains an invalid CSS selector. |
*/ |
-function parseFilter(text, ignore_headers) |
+function parseFilter(text, ignoreHeaders) |
{ |
text = Filter.normalize(text); |
if (!text) |
@@ -36,7 +36,7 @@ |
if (text[0] == "[") |
{ |
- if (ignore_headers) |
+ if (ignoreHeaders) |
return null; |
throw ext.i18n.getMessage("unexpected_filter_list_header"); |
@@ -73,14 +73,14 @@ |
* Parses and validates a newline-separated list of filters given by the user. |
* |
* @param {string} text |
* @param {Boolean} [ignore_headers=false] If true, filter list headers |
* will be stripped instead of |
* raising an exception. |
* @return {Filter[]} |
* @throws Will throw an exception if one of the filters cannot |
be parsed or contains an invalid CSS selector. |
*/ |
-function parseFilters(text, ignore_headers) |
+function parseFilters(text, ignoreHeaders) |
{ |
let lines = text.split("\n"); |
let filters = []; |
@@ -90,7 +90,7 @@ |
let filter; |
try |
{ |
- filter = parseFilter(lines[i], ignore_headers); |
+ filter = parseFilter(lines[i], ignoreHeaders); |
} |
catch (error) |
{ |
@@ -21,14 +21,14 @@ |
* |
* @param {string} text |
- * @param {Boolean} [ignore_headers=false] If true, no exception is raised |
- * for filter list headers, instead |
- * the function will return null. |
+ * @param {Boolean} [ignoreHeaders=false] If true, no exception is raised |
+ * for filter list headers, instead |
+ * the function will return null. |
* @return {Filter} |
* @throws Will throw an exception if filter cannot be |
@@ -73,14 +73,14 @@ |
* |
* @param {string} text |
- * @param {Boolean} [ignore_headers=false] If true, filter list headers |
- * will be stripped instead of |
- * raising an exception. |
+ * @param {Boolean} [ignoreHeaders=false] If true, filter list headers |
+ * will be stripped instead of |
+ * raising an exception. |
* @return {Filter[]} |
* @throws Will throw an exception if one of the filters cannot |